@@ -10,6 +10,7 @@ from aiohttp import web
 
 from aiortc import RTCPeerConnection, RTCSessionDescription
 from aiortc.contrib.media import MediaPlayer, MediaRelay
+from aiortc.rtcrtpsender import RTCRtpSender
 
 ROOT = os.path.dirname(__file__)
 
@@ -18,11 +19,11 @@ relay = None
 webcam = None
 
 
-def create_local_tracks(play_from):
+def create_local_tracks(play_from, decode):
     global relay, webcam
 
     if play_from:
-        player = MediaPlayer(play_from)
+        player = MediaPlayer(play_from, decode=decode)
         return player.audio, player.video
     else:
         options = {"framerate": "30", "video_size": "640x480"}
@@ -41,6 +42,15 @@ def create_local_tracks(play_from):
         return None, relay.subscribe(webcam.video)
 
 
+def force_codec(pc, sender, forced_codec):
+    kind = forced_codec.split("/")[0]
+    codecs = RTCRtpSender.getCapabilities(kind).codecs
+    transceiver = next(t for t in pc.getTransceivers() if t.sender == sender)
+    transceiver.setCodecPreferences(
+        [codec for codec in codecs if codec.mimeType == forced_codec]
+    )
+
+
 async def index(request):
     content = open(os.path.join(ROOT, "index.html"), "r").read()
     return web.Response(content_type="text/html", text=content)
@@ -66,14 +76,25 @@ async def offer(request):
             pcs.discard(pc)
 
     # open media source
-    audio, video = create_local_tracks(args.play_from)
+    audio, video = create_local_tracks(
+        args.play_from, decode=not args.play_without_decoding
+    )
+
+    if audio:
+        audio_sender = pc.addTrack(audio)
+        if args.audio_codec:
+            force_codec(pc, audio_sender, args.audio_codec)
+        elif args.play_without_decoding:
+            raise Exception("You must specify the audio codec using --audio-codec")
+
+    if video:
+        video_sender = pc.addTrack(video)
+        if args.video_codec:
+            force_codec(pc, video_sender, args.video_codec)
+        elif args.play_without_decoding:
+            raise Exception("You must specify the video codec using --video-codec")
 
     await pc.setRemoteDescription(offer)
-    for t in pc.getTransceivers():
-        if t.kind == "audio" and audio:
-            pc.addTrack(audio)
-        elif t.kind == "video" and video:
-            pc.addTrack(video)
 
     answer = await pc.createAnswer()
     await pc.setLocalDescription(answer)
@@ -101,6 +122,14 @@ if __name__ == "__main__":
     parser.add_argument("--cert-file", help="SSL certificate file (for HTTPS)")
     parser.add_argument("--key-file", help="SSL key file (for HTTPS)")
     parser.add_argument("--play-from", help="Read the media from a file and sent it."),
+    parser.add_argument(
+        "--play-without-decoding",
+        help=(
+            "Read the media without decoding it (experimental). "
+            "For now it only works with an MPEGTS container with only H.264 video."
+        ),
+        action="store_true",
+    )
     parser.add_argument(
         "--host", default="0.0.0.0", help="Host for HTTP server (default: 0.0.0.0)"
     )
@@ -108,6 +137,13 @@ if __name__ == "__main__":
         "--port", type=int, default=8080, help="Port for HTTP server (default: 8080)"
     )
     parser.add_argument("--verbose", "-v", action="count")
+    parser.add_argument(
+        "--audio-codec", help="Force a specific audio codec (e.g. audio/opus)"
+    )
+    parser.add_argument(
+        "--video-codec", help="Force a specific video codec (e.g. video/H264)"
+    )
+
     args = parser.parse_args()
 
     if args.verbose:
