@@ -37,6 +37,14 @@ class ConnectionKwargsTest(TestCase):
             {"stun_server": ("stun.l.google.com", 19302)},
         )
 
+    def test_stun_with_suffix(self):
+        self.assertEqual(
+            connection_kwargs(
+                [RTCIceServer("stun:global.stun.twilio.com:3478?transport=udp")]
+            ),
+            {"stun_server": ("global.stun.twilio.com", 3478)},
+        )
+
     def test_stun_multiple_servers(self):
         self.assertEqual(
             connection_kwargs(
